require "option_parser"
require "digest/sha256"
require "colorize"

require "./config"
require "./builder/cli"
require "./builder/run"
require "./scaffolder/cli"
require "./planner/cli"

module DocMachine
  class Cli
    def initialize
    end

    def start(argv)
      config = Config.new

      parser = OptionParser.new do |opts|
        opts.banner = [
          "Usage: #{PROGRAM_NAME} [options]",
          "",
          "Main options:"
        ].join("\n")

        opts.on("-v", "--verbose", "Enable verbosity") do |verbose|
          config.verbose = true
        end

        opts.on("-h", "--help", "Show this help") do
          puts opts
          exit
        end

        opts.separator ""
        opts.separator "Commands:"

        DocMachine::Builder::Cli.add_options(opts, config)
        DocMachine::Scaffolder::Cli.add_options(opts, config)
        DocMachine::Planner::Cli.add_options(opts, config)
      end

      parser.parse(ARGV)

      builder = DocMachine::Builder::Run.new(config)
      builder.prepare
      builder.start
      builder.wait
    end
  end
end
